# Zafkiel

**A cross-platform UI automation framework based on [Airtest](https://github.com/AirtestProject/Airtest) and [StarRailCopilot](https://github.com/LmeSzinc/StarRailCopilot).**

**基于[Airtest](https://github.com/AirtestProject/Airtest)和[StarRailCopilot](https://github.com/LmeSzinc/StarRailCopilot)的跨平台UI自动化框架。**

## Overview

Zafkiel is a secondary encapsulation of Airtest, integrating the page logic, OCR capabilities and other advanced features of StarRailCopilot, aiming to provide more powerful and flexible automated testing capabilities.

## Examples

- [HonkaiHelper](https://github.com/Aues6uen11Z/HonkaiHelper), Honkai Impact 3rd automation script.

## License

This project is licensed under [GPL-3.0](LICENSE) . 

In addition, this project uses the following open source libraries:

\- [Airtest](https://github.com/AirtestProject/Airtest), the license can be viewed [here](https://github.com/AirtestProject/Airtest/blob/master/LICENSE)

\- [StarRailCopilot](https://github.com/StarRailCopilot/StarRailCopilot), the license can be viewed [here](https://github.com/LmeSzinc/StarRailCopilot/blob/master/LICENSE)